@@ -1,4 +1,4 @@
-;; Copyright (C) 2015-2019 Free Software Foundation, Inc
+;; Copyright (C) 2015-2019, 2026 Free Software Foundation, Inc
 ;; Author: Rocky Bernstein <rocky@gnu.org>
 
 ;; This program is free software; you can redistribute it and/or modify
@@ -80,11 +80,14 @@
   regexp-hash          ;; hash table of regular expressions appropriate for
                        ;; this debugger. Eventually loc-regexp, file-group
                        ;; and line-group below will removed and stored here.
-  srcbuf-list          ;; list of source buffers we have stopped at
+  srcbuf-list          ;; list of source buffers we have encountered. This includes buffers
+                       ;; that have been stopped at or attached.
   source-path          ;; last source-code path we've seen
 
   bt-buf               ;; backtrace buffer if it exists
   brkpt-buf            ;; breakpoint buffer if it exists
+  locals-buf           ;; locals buffer if it exists
+  locals-data          ;; hash that holds data for locals-buffer
   bp-list              ;; list of breakpoints
   divert-output?       ;; Output is part of a conversation between front-end
                        ;; debugger.
@@ -102,6 +105,7 @@
   loc-regexp   ;; Location regular expression string
   file-group
   line-group
+  column-group
   alt-file-group
   alt-line-group
   text-group
@@ -150,6 +154,7 @@
 (realgud-struct-field-setter "realgud-cmdbuf-info" "bp-list")
 (realgud-struct-field-setter "realgud-cmdbuf-info" "bt-buf")
 (realgud-struct-field-setter "realgud-cmdbuf-info" "brkpt-buf")
+(realgud-struct-field-setter "realgud-cmdbuf-info" "locals-buf")
 (realgud-struct-field-setter "realgud-cmdbuf-info" "cmd-args")
 (realgud-struct-field-setter "realgud-cmdbuf-info" "last-input-end")
 (realgud-struct-field-setter "realgud-cmdbuf-info" "divert-output?")
@@ -455,6 +460,8 @@ values set in the debugger's init.el."
 	     :srcbuf-list nil
 	     :bt-buf nil
 	     :brkpt-buf nil
+	     :locals-buf nil
+	     :locals-data (make-hash-table :test 'equal)
 	     :bp-list nil
 	     :divert-output? nil
 	     :cmd-hash cmd-hash
@@ -573,5 +580,13 @@ command-process buffer has stored."
       ))
   )
 
+(defun realgud-get-info (key &optional opt-buffer)
+  "Convinient function for getting data from realgud-cmdbuf-info."
+  (let* ((buffer (or opt-buffer (current-buffer)))
+	 (cmdbuf (realgud-get-cmdbuf buffer)))
+    (if cmdbuf
+	(with-current-buffer-safe cmdbuf
+	  (realgud-sget 'cmdbuf-info key))
+      (error "Unable to find cmdbuf for '%s'" buffer)) ))
 
 (provide-me "realgud-buffer-")
